@@ -1,4 +1,4 @@
-from test import testfunc
+from . import hoge
 
 __copyright__    = 'Copyright (C) 2018 Your Name'
 __version__      = '1.0.0'
@@ -7,4 +7,4 @@ __author__       = 'Your Name'
 __author_email__ = 'Your@Email'
 __url__          = 'http://github.com/account/repository'
 
-__all__ = ['testfunc']
+__all__ = ['hoge']
